@@ -479,7 +479,7 @@ Rcpp::List cstep(const arma::cube& X,
                           Named("cov_row_inv") = cstep.est.cov_row_inv,
                           Named("cov_col_inv") = cstep.est.cov_col_inv,
                           Named("det") = cstep.det,
-                          Named("h_subset") = cstep.h_subset,
+                          Named("h_subset") = cstep.h_subset + 1,
                           Named("dets") = cstep.dets,
                           Named("iterations") = cstep.iterations);
   return(res);
@@ -821,8 +821,8 @@ Rcpp::List mmcd(const arma::cube& X,
                           Named("consistency_factors") = scale_factors,
                           Named("dets") = dets,
                           Named("best_i") = best_i,
-                          Named("h_subset") = csteps[best_i].h_subset,
-                          Named("h_subset_reweighted") = h_subset_reweighted,
+                          Named("h_subset") = csteps[best_i].h_subset + 1,
+                          Named("h_subset_reweighted") = h_subset_reweighted + 1,
                           Named("iterations") = iterations,
                           Named("dets_init_first") = dets_init_first,
                           Named("subsets_first") = subsets_first,
